@@ -12,7 +12,7 @@ use File::ShareDir ();
 use Dist::Zilla::Util::CurrentCmd ();
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '2.04'; # VERSION
+our $VERSION = '2.06'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -32,7 +32,7 @@ sub mvp_multivalue_args { qw(
 
 my %plugin_versions = qw(
   Alien                0.023
-  Author::Plicease.*   2.04
+  Author::Plicease.*   2.06
   OurPkgVersion        0.06
   MinimumPerl          1.006
   InstallGuide         1.200006
@@ -104,7 +104,7 @@ sub configure
     if -r "inc/run/test.pl";
 
   $self->_my_add_plugin(
-    ['GatherDir' => { exclude_filename => [qw( Makefile.PL Build.PL cpanfile )],
+    ['GatherDir' => { exclude_filename => [qw( Makefile.PL Build.PL cpanfile xt/release/changes.t xt/release/fixme.t )],
                       exclude_match => '^_build/' }, ],
     [ PruneCruft => { except => '.travis.yml' } ],
     [ 'ManifestSkip' ],
@@ -291,7 +291,8 @@ sub configure
     }
   }
 
-  foreach my $name (qw( t/00_diag.txt t/00_diag.pre.txt xt/release/build_environment.t xt/release/unused.t ))
+  foreach my $name (qw( t/00_diag.txt t/00_diag.pre.txt ), 
+                      map { "xt/release/$_.t" } qw( build_environment unused eol no_tabs pod strict fixme changes pod_coverage pod_spelling_common pod_spelling_system version ))
   {  
     if(-e $name)
     {
@@ -319,7 +320,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.04
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -377,6 +378,8 @@ This plugin bundle is mostly equivalent to
  exclude_filename = Makefile.PL
  exclude_filename = Build.PL
  exclude_filename = cpanfile
+ exclude_filename = xt/release/changes.t
+ exclude_filename = xt/release/fixme.t
  exclude_match = ^_build/
  
  [PruneCruft]
